@@ -15,6 +15,20 @@ from inforion.excelexport import *
 from inforion.helper.filehandling import *
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
+
+import logging
+import os.path
+import os
+
+import logging
+from logger import get_logger
+
+from inforion.datacatalog.datacatalog import (
+    post_datacatalog_object,
+    delete_datacatalog_object,
+    ObjectSchemaType,
+)
+from inforion.messaging.messaging import post_messaging_v2_multipart_message
 from inforion.ionapi.model import inforlogin
 from inforion.messaging.messaging import post_messaging_v2_multipart_message
 
@@ -112,7 +126,7 @@ def load(
                 inputfile = config_json["inputfile"]
                 outputfile = config_json["outputfile"]
             else:
-                print("JSON File wrong config")
+                logging.error("JSON File wrong config")
                 sys.exit(0)
             if "start" in config_json:
                 start = config_json["start"]
@@ -139,9 +153,9 @@ def load(
 def extract(program, outputfile):
 
     if not "program" in locals() or not program:
-        print("\033[91m" + "Error: Program name is missing" + "\033[0m")
+        logging.info("\033[91m" + "Error: Program name is missing" + "\033[0m")
     if not "outputfile" in locals() or not outputfile:
-        print("\033[91m" + "Error: Output filename is missing" + "\033[0m")
+        logging.info("\033[91m" + "Error: Output filename is missing" + "\033[0m")
 
     if program and outputfile:
         generate_api_template_file(program, outputfile)
