@@ -13,10 +13,10 @@ def get_messaging_ping():
         url = inforlogin.base_url() + '/IONSERVICES/api/ion/messaging/service/ping'
         headers = inforlogin.header()
         res = requests.get(url, headers=headers)
-        log.info('messaging ping: {}'.format(res.content))
+        logger.info('messaging ping: {}'.format(res.content))
         return res
     except Exception as e:
-        log.error("Error ocurred " + str(e))
+        logger.error("Error ocurred " + str(e))
 
 
 
@@ -32,8 +32,8 @@ def post_messaging_v2_multipart_message(parameter_request, message_payload):
         headers.update({'Content-Type': data.content_type})
 
         res = requests.post(url, headers=headers, data=data)
-        log.info('messaging v2 multipart message: {}'.format(res.content))
+        logger.info('messaging v2 multipart message: {}'.format(res.content))
         return res
     except Exception as e:
-        log.error("Error ocurred " + str(e))
+        logger.error("Error ocurred " + str(e))
 
